package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseMaterialtypeInfo;

/**
 * 物料类型基础信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-22
 */
public interface BaseMaterialtypeInfoMapper 
{
    /**
     * 查询物料类型基础信息
     * 
     * @param objid 物料类型基础信息ID
     * @return 物料类型基础信息
     */
    public BaseMaterialtypeInfo selectBaseMaterialtypeInfoById(Long objid);

    /**
     * 查询物料类型基础信息列表
     * 
     * @param baseMaterialtypeInfo 物料类型基础信息
     * @return 物料类型基础信息集合
     */
    public List<BaseMaterialtypeInfo> selectBaseMaterialtypeInfoList(BaseMaterialtypeInfo baseMaterialtypeInfo);

    /**
     * 新增物料类型基础信息
     * 
     * @param baseMaterialtypeInfo 物料类型基础信息
     * @return 结果
     */
    public int insertBaseMaterialtypeInfo(BaseMaterialtypeInfo baseMaterialtypeInfo);

    /**
     * 修改物料类型基础信息
     * 
     * @param baseMaterialtypeInfo 物料类型基础信息
     * @return 结果
     */
    public int updateBaseMaterialtypeInfo(BaseMaterialtypeInfo baseMaterialtypeInfo);

    /**
     * 删除物料类型基础信息
     * 
     * @param objid 物料类型基础信息ID
     * @return 结果
     */
    public int deleteBaseMaterialtypeInfoById(Long objid);

    /**
     * 批量删除物料类型基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseMaterialtypeInfoByIds(String[] objids);

    public List<BaseMaterialtypeInfo> selectAddBaseMaterialtypeInfoList();

}
